@@ -23,7 +23,7 @@ from aliyunsdkmse.endpoint import endpoint_data
 class ListClusterTypesRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'mse', '2019-05-31', 'ListClusterTypes','mse')
+		RpcRequest.__init__(self, 'mse', '2019-05-31', 'ListClusterTypes')
 		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
@@ -31,6 +31,11 @@ class ListClusterTypesRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_ConnectType(self): # String
+		return self.get_query_params().get('ConnectType')
+
+	def set_ConnectType(self, ConnectType):  # String
+		self.add_query_param('ConnectType', ConnectType)
 	def get_AcceptLanguage(self): # String
 		return self.get_query_params().get('AcceptLanguage')
 
