@@ -41,3 +41,8 @@ class ListZnodeChildrenRequest(RpcRequest):
 
 	def set_Path(self, Path):  # String
 		self.add_query_param('Path', Path)
+	def get_AcceptLanguage(self): # String
+		return self.get_query_params().get('AcceptLanguage')
+
+	def set_AcceptLanguage(self, AcceptLanguage):  # String
+		self.add_query_param('AcceptLanguage', AcceptLanguage)
