@@ -36,3 +36,8 @@ class QueryClusterDiskSpecificationRequest(RpcRequest):
 
 	def set_ClusterType(self, ClusterType):  # String
 		self.add_query_param('ClusterType', ClusterType)
+	def get_AcceptLanguage(self): # String
+		return self.get_query_params().get('AcceptLanguage')
+
+	def set_AcceptLanguage(self, AcceptLanguage):  # String
+		self.add_query_param('AcceptLanguage', AcceptLanguage)
