@@ -56,3 +56,8 @@ class ScalingClusterRequest(RpcRequest):
 
 	def set_InstanceCount(self, InstanceCount):  # Integer
 		self.add_query_param('InstanceCount', InstanceCount)
+	def get_AcceptLanguage(self): # String
+		return self.get_query_params().get('AcceptLanguage')
+
+	def set_AcceptLanguage(self, AcceptLanguage):  # String
+		self.add_query_param('AcceptLanguage', AcceptLanguage)
